@@ -22,6 +22,7 @@
  */
 
 #include "pygi-private.h"
+#include "pygi-cache.h"
 
 #include <pygobject.h>
 #include <pyglib-python-compat.h>
@@ -37,6 +38,8 @@ _base_info_dealloc (PyGIBaseInfo *self)
 
     g_base_info_unref (self->info);
 
+    _pygi_callable_cache_free(self->cache);
+
     Py_TYPE( (PyObject *) self)->tp_free ( (PyObject *) self);
 }
 
@@ -162,9 +165,6 @@ _pygi_info_new (GIBaseInfo *info)
         case GI_INFO_TYPE_CONSTANT:
             type = &PyGIConstantInfo_Type;
             break;
-        case GI_INFO_TYPE_ERROR_DOMAIN:
-            type = &PyGIErrorDomainInfo_Type;
-            break;
         case GI_INFO_TYPE_UNION:
             type = &PyGIUnionInfo_Type;
             break;
@@ -192,6 +192,9 @@ _pygi_info_new (GIBaseInfo *info)
         case GI_INFO_TYPE_UNRESOLVED:
             type = &PyGIUnresolvedInfo_Type;
             break;
+        default:
+            g_assert_not_reached();
+            break;
     }
 
     self = (PyGIBaseInfo *) type->tp_alloc (type, 0);
@@ -430,12 +433,8 @@ _pygi_g_type_info_size (GITypeInfo *type_info)
         case GI_TYPE_TAG_DOUBLE:
         case GI_TYPE_TAG_GTYPE:
         case GI_TYPE_TAG_UNICHAR:
-            if (g_type_info_is_pointer (type_info)) {
-                size = sizeof (gpointer);
-            } else {
-                size = _pygi_g_type_tag_size (type_tag);
-                g_assert (size > 0);
-            }
+            size = _pygi_g_type_tag_size (type_tag);
+            g_assert (size > 0);
             break;
         case GI_TYPE_TAG_INTERFACE:
         {
@@ -481,7 +480,6 @@ _pygi_g_type_info_size (GITypeInfo *type_info)
                 case GI_INFO_TYPE_INVALID:
                 case GI_INFO_TYPE_FUNCTION:
                 case GI_INFO_TYPE_CONSTANT:
-                case GI_INFO_TYPE_ERROR_DOMAIN:
                 case GI_INFO_TYPE_VALUE:
                 case GI_INFO_TYPE_SIGNAL:
                 case GI_INFO_TYPE_PROPERTY:
@@ -489,6 +487,7 @@ _pygi_g_type_info_size (GITypeInfo *type_info)
                 case GI_INFO_TYPE_ARG:
                 case GI_INFO_TYPE_TYPE:
                 case GI_INFO_TYPE_UNRESOLVED:
+                default:
                     g_assert_not_reached();
                     break;
             }
@@ -860,7 +859,6 @@ pygi_g_struct_info_is_simple (GIStructInfo *struct_info)
                     case GI_INFO_TYPE_INVALID:
                     case GI_INFO_TYPE_FUNCTION:
                     case GI_INFO_TYPE_CONSTANT:
-                    case GI_INFO_TYPE_ERROR_DOMAIN:
                     case GI_INFO_TYPE_VALUE:
                     case GI_INFO_TYPE_SIGNAL:
                     case GI_INFO_TYPE_PROPERTY:
@@ -868,7 +866,9 @@ pygi_g_struct_info_is_simple (GIStructInfo *struct_info)
                     case GI_INFO_TYPE_ARG:
                     case GI_INFO_TYPE_TYPE:
                     case GI_INFO_TYPE_UNRESOLVED:
+                    default:
                         g_assert_not_reached();
+                        break;
                 }
 
                 g_base_info_unref (info);
